==> fun_apis_cli-0.2.2.tar.gz: fun_apis_cli-0.2.2/README_PyPi.md <==
![LOGO](https://raw.githubusercontent.com/tahadnan/Fun-APIs-CLI/main/Fun_APIs_logo.png)

# Fun APIs CLI

A simple Python command-line interface utility to interact with various fun APIs: facts, animals, quotes...
This project, designed for learning and fun, can pull random facts, animal data, quotes and much more via API Ninjas and other API sources.

## Installation

```bash
pip install fun-apis-cli
```
## Configuration

1. Acquire the needed API-Keys, head to the [project wiki](https://github.com/tahadnan/Fun-APIs-CLI/wiki) for more info about this step.
2. Run ```pip install fun-apis-cli -c``` and you will be prompted to enter the required APIs keys.

## WHAT'S NEW WITH 0.2.1:
- Fixed the inconsistent superhero verification
mechanism
- Improved the way Names and IDs are stored in the
JSON file "Name": id => "id":"Name"
- Provided a way to view available heroes in table
form
- Remove unused imports
- Fix f-strings without placeholders
- Resolve undefined name warnings


## Contributing

This project relies on collaboration and community support! It's designed to be an evolving, living tool, and while it currently supports APIs for fun facts, animals, and quotes, the possibilities are endless. Whether you'd like to add new APIs, enhance existing features, refine the code, or even update the documentation, contributions are welcome. Let's make this CLI a better and more diverse tool together. You can fork the repository, look at the code, and send your pull requests-we are excited to see what you will add to the project!

==> fun_apis_cli-0.2.4.tar.gz: fun_apis_cli-0.2.4/README_PyPi.md <==
![LOGO](https://raw.githubusercontent.com/tahadnan/Fun-APIs-CLI/main/Fun_APIs_logo.png)

# Fun APIs CLI

A simple Python command-line interface utility to interact with various fun APIs: facts, animals, quotes...
This project, designed for learning and fun, can pull random facts, animal data, quotes and much more via API Ninjas and other API sources.

## Installation

```bash
pip install fun-apis-cli
```
## Configuration

1. Acquire the needed API-Keys, head to the [project wiki](https://github.com/tahadnan/Fun-APIs-CLI/wiki) for more info about this step.
2. Run ```fun-apis-cli -c``` and you will be prompted to enter the required APIs keys.

## WHAT'S NEW WITH 0.2.1:
- Fixed the inconsistent superhero verification
mechanism
- Improved the way Names and IDs are stored in the
JSON file "Name": id => "id":"Name"
- Provided a way to view available heroes in table
form
- Remove unused imports
- Fix f-strings without placeholders
- Resolve undefined name warnings


## Contributing

This project relies on collaboration and community support! It's designed to be an evolving, living tool, and while it currently supports APIs for fun facts, animals, and quotes, the possibilities are endless. Whether you'd like to add new APIs, enhance existing features, refine the code, or even update the documentation, contributions are welcome. Let's make this CLI a better and more diverse tool together. You can fork the repository, look at the code, and send your pull requests-we are excited to see what you will add to the project!
